@@ -169,15 +169,15 @@ as.MAList <- function(object) {
 } 
 
 #  Gordon Smyth, 28 Oct 2004
-as.matrix.RGList <- function(x) normalizeWithinArrays(x,method="none")$M
-as.matrix.MAList <- function(x) as.matrix(x$M)
-as.matrix.MArrayLM <- function(x) x$coefficients
-as.matrix.marrayNorm <- function(x) x@maM
-as.matrix.exprSet <- function(x) x@exprs
+as.matrix.RGList <- function(x,...) normalizeWithinArrays(x,method="none")$M
+as.matrix.MAList <- function(x,...) as.matrix(x$M)
+as.matrix.MArrayLM <- function(x,...) x$coefficients
+as.matrix.marrayNorm <- function(x,...) x@maM
+as.matrix.exprSet <- function(x,...) x@exprs
 #  13 July 2006
-as.matrix.PLMset <- function(x) x@chip.coefs
+as.matrix.PLMset <- function(x,...) x@chip.coefs
 #  19 Dec 2006
-as.matrix.ExpressionSet <- function(x) get("exprs",env=x@assayData)
+as.matrix.ExpressionSet <- function(x,...) get("exprs",env=x@assayData)
 
 if(getRversion() >= "2.4.0") {
 
